@@ -13,12 +13,12 @@ pub fn listen<A: std::net::ToSocketAddrs>(address: A) -> std::io::Result<()> {
             0 => { get_raw(address) } //raw protocol
             71 => { get_http(address) } //71 represents ASCII letter G which is sent from an HTTP GET request
             _ => { return Err(std::io::Error::new(std::io::ErrorKind::InvalidData, concat!("bad protocol: must be ", env!("CARGO_PKG_NAME"), "or HTTP GET"))); }
-        }?)?;
+        })?;
     }
     Ok(())
 }
 
-fn get_raw(address: std::net::IpAddr) -> std::io::Result<Vec<u8>> {
+fn get_raw(address: std::net::IpAddr) -> Vec<u8> {
     let mut response: Vec<u8> = Vec::new();
     match address {
         std::net::IpAddr::V4(ip) => {
@@ -30,10 +30,10 @@ fn get_raw(address: std::net::IpAddr) -> std::io::Result<Vec<u8>> {
             response.extend_from_slice(&ip.octets()) //16 bytes
         }
     };
-    Ok(response)
+    return response;
 }
 
-fn get_http(address: std::net::IpAddr) -> std::io::Result<Vec<u8>> {
+fn get_http(address: std::net::IpAddr) -> Vec<u8> {
     let mut headers: Vec<u8> = Vec::new();
     let mut body: Vec<u8> = Vec::new();
 
@@ -53,5 +53,21 @@ fn get_http(address: std::net::IpAddr) -> std::io::Result<Vec<u8>> {
     let mut response = headers;
     response.extend_from_slice(&body);
 
-    Ok(response)
+    return response;
+}
+
+#[cfg(test)]
+mod test {
+    use std::str::FromStr;
+    use super::*;
+
+    #[test]
+    fn test_get_raw() {
+        assert_eq!(*get_raw(std::net::IpAddr::from_str("127.0.0.1").unwrap()), [0, 127, 0, 0, 1]);
+    }
+
+    #[test]
+    fn test_get_http() {
+        assert_eq!(*get_http(std::net::IpAddr::from_str("127.0.0.1").unwrap()), *"HTTP/1.1 200 OK\r\nContent-Type: text/plain;\r\nContent-Length: 9\r\n\r\n127.0.0.1".as_bytes());
+    }
 }
\ No newline at end of file
